"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var forms_1 = require("@angular/forms");
var router_1 = require("@angular/router");
var ayuda_service_1 = require("../../service/ayuda.service");
var session_shared_service_1 = require("../../service/session-shared.service");
var bitdropdown_general_component_1 = require("./bitdropdown-general.component");
exports.CUSTOM_DROPDOWN_MULTIPLE_CONTROL_VALUE_ACCESSOR = {
    provide: forms_1.NG_VALUE_ACCESSOR,
    useExisting: core_1.forwardRef(function () { return BitDropDownMultipleComponent; }),
    multi: true
};
/**
 * Clase que utiliza un custom componente para select múltiple de elementos
 * Utiliza la interfaz ControlValueAccessor
 *    <bit-select [domain]="'DOMAIN_TIPO_LOG'" id="tipolog" [control]="formControl"">&nbsp;&nbsp;Tipus d'operació</bit-select>
 *
 * @input data: array de objetos a mostrar en el select. Puede ser null, en cuyo caso domain no puede ser null
 * @input domain: nombre del dominio que contiene los datos y que nos resolverá la página cuando cargue el componente. Puede ser null, en cuyo caso data no puede ser null
 * @input id: identificador del componente select
 **/
var BitDropDownMultipleComponent = /** @class */ (function (_super) {
    __extends(BitDropDownMultipleComponent, _super);
    // Si se pueden seleccionar muchos elementos, que el label de los elementos seleccionados no
    // aparezca dentro del select, y hacerlo como una lista fuera del select.
    function BitDropDownMultipleComponent(router, sessionShared, ayudaService, changeDetectorRef) {
        var _this = _super.call(this, router, sessionShared, ayudaService, changeDetectorRef) || this;
        _this.router = router;
        _this.sessionShared = sessionShared;
        _this.ayudaService = ayudaService;
        _this.changeDetectorRef = changeDetectorRef;
        _this.emptyText = "Cap";
        _this.maxSelectedLabels = 3;
        _this.showSeparateSelectedLabels = false; // indica si se muestran los elementos seleccionados en una columna separada
        return _this;
    }
    BitDropDownMultipleComponent.prototype.ngOnChanges = function (changes) {
        for (var propName in changes) {
            var changedProp = changes[propName];
            if (propName === "data") {
                this.listaOpciones = changedProp.currentValue ? changedProp.currentValue.slice() : [];
                this.postRetrieveData();
            }
            else if (propName === "dominio") {
                this.domain = changedProp.currentValue;
                // TODO: recargar dominio por si es distinto?
            }
        }
    };
    // custom processing after retrieving data array from service
    BitDropDownMultipleComponent.prototype.postRetrieveData = function () { };
    Object.defineProperty(BitDropDownMultipleComponent.prototype, "value_lectura", {
        get: function () {
            var val = this.value;
            var labels = this.listaOpciones && this.listaOpciones.filter(function (d) { return val && val.indexOf(d.value) > -1; }).map(function (d) { return d.label; });
            return labels ? labels.join(", ") : null;
        },
        enumerable: true,
        configurable: true
    });
    BitDropDownMultipleComponent.prototype.labelSelectedItem = function (id) {
        return this.listaOpciones.find(function (c) { return c.value == id; }).label;
    };
    BitDropDownMultipleComponent.prototype.deleteSelectedItem = function (event, item) {
        event.preventDefault();
        var index = this.value.indexOf(item);
        this.value.splice(index, 1);
        // se clona el array. Si no, el texto "{0} elementos seleccionados" del select de Prime no se actualiza.
        this.value = this.value.slice(0);
    };
    BitDropDownMultipleComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: "bit-dropdown-multiple",
                    template: "\n    <div class=\"row separador\" *ngIf=\"showSeparateSelectedLabels; else normalBitSelectMultiple\">\n        <div> <!-- class=\"col-sm-4\"-->\n            <ng-container *ngTemplateOutlet=\"normalBitSelectMultiple\"></ng-container>\n        </div>\n        <div><!-- elementos seleccionados -->\n            <label>&nbsp;</label>\n            <div class=\"multiselect-labels\">\n                <div class=\"label label-primary multiselect-labels-lg\" *ngFor=\"let item of value\">\n                <span>{{labelSelectedItem(item)}}</span>\n                <a (click)=\"deleteSelectedItem($event, item)\" title=\"{{title}}}\"> <i class=\"fa fa-times\"></i></a>\n                </div>\n            </div>\n        </div>\n    </div>\n    <ng-template #normalBitSelectMultiple>\n        <label *ngIf=\"!hideLabel\"><ng-content></ng-content>&nbsp;<span *ngIf=\"obligatorio\" class=\"fa fa-asterisk\"></span>&nbsp;&nbsp;\n            <i *ngIf=\"ayuda\" (click)=\"showAyuda()\" class=\"btn-ayuda fa fa-question\"></i>\n        </label>\n        <p *ngIf=\"readOnly\" class=\"lectura\">{{value_lectura}}</p>\n        <div *ngIf=\"!readOnly\">\n            <p-multiSelect \n                *ngIf=\"!readOnly\" \n                id=\"{{id}}\" \n                [(ngModel)]=\"value\"             \n                [options]=\"listaOpciones\" \n                [defaultLabel]=\"emptyText\"             \n                [maxSelectedLabels]=\"maxSelectedLabels\"\n                selectedItemsLabel=\"{0} elements seleccionats\"\n                (onFocus)=\"onFocus()\" \n                (onBlur)=\"onBlur()\">             \n            </p-multiSelect>\n        <control-messages *ngIf=\"control!=null\" [control]=\"control\" [field]=\"id\"></control-messages>\n        </div>\n    </ng-template>\n  ",
                    providers: [exports.CUSTOM_DROPDOWN_MULTIPLE_CONTROL_VALUE_ACCESSOR]
                },] },
    ];
    /** @nocollapse */
    BitDropDownMultipleComponent.ctorParameters = function () { return [
        { type: router_1.ActivatedRoute },
        { type: session_shared_service_1.SessionSharedService },
        { type: ayuda_service_1.AyudaService },
        { type: core_1.ChangeDetectorRef }
    ]; };
    BitDropDownMultipleComponent.propDecorators = {
        emptyText: [{ type: core_1.Input }],
        maxSelectedLabels: [{ type: core_1.Input }],
        showSeparateSelectedLabels: [{ type: core_1.Input }],
        title: [{ type: core_1.Input }]
    };
    return BitDropDownMultipleComponent;
}(bitdropdown_general_component_1.BitDropDownGeneralComponent));
exports.BitDropDownMultipleComponent = BitDropDownMultipleComponent;
//# sourceMappingURL=bit-dropdown-multiple.component.js.map