"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var forms_1 = require("@angular/forms");
/**
 *  Clase general que todos los componentes personalizados deben extender. Contiene toda la lógica común para trabajar con
 * componentes personalizados
 */
var BitGeneralComponent = /** @class */ (function () {
    function BitGeneralComponent(ayudaService) {
        this.ayudaService = ayudaService;
        this.placeholder = "";
        this.readOnly = false;
        this.hideLabel = false; // forzar que no se reserve espacio para el nombre del campo
        this.forceObligatorio = false;
        this.onChange = new core_1.EventEmitter();
    }
    /**Debemos suscribirnos a los cambios del FormControl para emitir mediante onChange el evento con el nuevo valor que tiene el componente */
    BitGeneralComponent.prototype.ngOnInit = function () {
        var _this = this;
        if (this.control) {
            this.control.valueChanges.subscribe(function (value) {
                _this.onChange.emit(value);
            });
        }
        else {
            console.log("control no definido para " + this.nombre);
        }
    };
    /** Controlamos si debemos modificar el valor interno del componente mediante una transformacion al tener un pipe asociado*/
    BitGeneralComponent.prototype.onBlur = function () {
        if (this.instanciaPipe != null) {
            this.control.setValue(this.instanciaPipe.transform(this.control.value));
        }
    };
    BitGeneralComponent.prototype.onFocus = function () {
        if (this.instanciaPipe != null) {
            this.control.setValue(this.instanciaPipe.parse(this.control.value));
            this.control.updateValueAndValidity();
        }
    };
    Object.defineProperty(BitGeneralComponent.prototype, "obligatorio", {
        // decidimos marcar el campo como obligatorio si se ha indicado a la fuerza (por parámetro)
        // o si el control de formulario asociado está saltando por ser obligatorio y no haberse rellenado
        get: function () {
            return this.forceObligatorio || (this.control && this.control.errors && this.control.errors["required"]);
        },
        enumerable: true,
        configurable: true
    });
    BitGeneralComponent.prototype.showAyuda = function () {
        this.ayudaService.mostrarAyuda(this.ayuda);
    };
    Object.defineProperty(BitGeneralComponent.prototype, "value_lectura", {
        get: function () {
            return this.control.value;
        },
        enumerable: true,
        configurable: true
    });
    BitGeneralComponent.propDecorators = {
        control: [{ type: core_1.Input }],
        nombre: [{ type: core_1.Input }],
        nombreDirectiva: [{ type: core_1.Input }],
        label: [{ type: core_1.Input }],
        estilo: [{ type: core_1.Input }],
        tooltipTexto: [{ type: core_1.Input }],
        tooltipPosicion: [{ type: core_1.Input }],
        ayuda: [{ type: core_1.Input }],
        placeholder: [{ type: core_1.Input }],
        readOnly: [{ type: core_1.Input }],
        hideLabel: [{ type: core_1.Input }],
        instanciaPipe: [{ type: core_1.Input }],
        forceObligatorio: [{ type: core_1.Input }],
        onChange: [{ type: core_1.Output }]
    };
    return BitGeneralComponent;
}());
exports.BitGeneralComponent = BitGeneralComponent;
//# sourceMappingURL=bit-general.component.js.map