"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var ayuda_service_1 = require("../../service/ayuda.service");
var general_utils_service_1 = require("../../service/general-utils.service");
var router_1 = require("@angular/router");
var session_shared_service_1 = require("../../service/session-shared.service");
var BitReadonlyComponent = /** @class */ (function () {
    function BitReadonlyComponent(router, sessionShared, ayudaService) {
        this.router = router;
        this.sessionShared = sessionShared;
        this.ayudaService = ayudaService;
        this.hideLabel = false;
        this.opcionesDropdown = [];
    }
    BitReadonlyComponent.prototype.ngOnInit = function () {
        var _this = this;
        if (!!this.domain && !this.data) {
            this.router.data.subscribe(function (result) {
                var dominios = result["dominios"];
                var domainTipo = dominios[_this.domain];
                if (domainTipo != null) {
                    domainTipo.subscribe(function (result) {
                        //console.log(result);
                        _this.sessionShared.set(_this.domain, result.slice()); // almacenamos en sesión una copia para evitar transmitir cambios
                        _this.opcionesDropdown = result.slice();
                    }, function (error) {
                        console.log('Error carrega dominis', _this.domain, error);
                    });
                }
                else {
                    console.log("Domini sense dades", _this.domain);
                }
            });
        }
        else if (this.data) {
            this.opcionesDropdown = this.data.slice();
        }
    };
    BitReadonlyComponent.prototype.showAyuda = function () {
        this.ayudaService.mostrarAyuda(this.ayuda);
    };
    Object.defineProperty(BitReadonlyComponent.prototype, "value_lectura", {
        get: function () {
            var _this = this;
            this.tipo = this.tipo || 'text';
            switch (this.tipo) {
                case 'date':
                    return this.valor ? general_utils_service_1.GeneralUtils.getDateAsString(general_utils_service_1.GeneralUtils.stringShortToDate(this.valor)) : '';
                case 'datetime':
                    return this.valor ? general_utils_service_1.GeneralUtils.getDateTimeAsString(general_utils_service_1.GeneralUtils.stringToDate(this.valor)) : '';
                case 'time':
                    return this.valor ? general_utils_service_1.GeneralUtils.getTimeAsString(general_utils_service_1.GeneralUtils.stringToTime(this.valor)) : '';
                case 'boolean':
                    return this.valor ? 'Sí' : 'No';
                case 'list':
                    var d = this.opcionesDropdown.find(function (d) { return d.value == _this.valor; });
                    return d ? d.label : '';
                case 'list-multiple':
                    var labels = this.opcionesDropdown && this.opcionesDropdown.filter(function (d) { return _this.valor && _this.valor.indexOf(d.value) > -1; }).map(function (d) { return d.label; });
                    return labels ? labels.join(", ") : null;
                default:
                    return this.valor;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitReadonlyComponent.prototype, "isTextarea", {
        get: function () {
            return this.tipo === 'textarea';
        },
        enumerable: true,
        configurable: true
    });
    BitReadonlyComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: "bit-readonly",
                    template: "\n    <label *ngIf=\"!hideLabel\">\n        <ng-content></ng-content>&nbsp;&nbsp;\n        <i *ngIf=\"ayuda\" class=\"btn-ayuda fa fa-question\" (click)=\"showAyuda()\"></i>\n    </label>\n    <p *ngIf=\"!isTextarea\" class=\"lectura\">{{value_lectura}}</p>\n    <pre *ngIf=\"isTextarea\" class=\"lectura\">{{value_lectura}}</pre>\n  "
                },] },
    ];
    /** @nocollapse */
    BitReadonlyComponent.ctorParameters = function () { return [
        { type: router_1.ActivatedRoute },
        { type: session_shared_service_1.SessionSharedService },
        { type: ayuda_service_1.AyudaService }
    ]; };
    BitReadonlyComponent.propDecorators = {
        ayuda: [{ type: core_1.Input }],
        valor: [{ type: core_1.Input }],
        tipo: [{ type: core_1.Input }],
        hideLabel: [{ type: core_1.Input }],
        data: [{ type: core_1.Input }],
        domain: [{ type: core_1.Input }]
    };
    return BitReadonlyComponent;
}());
exports.BitReadonlyComponent = BitReadonlyComponent;
//# sourceMappingURL=bit-readonly.component.js.map