"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var bit_custom_component_1 = require("./bit-custom.component");
/**
 * Clase que utiliza un custom componente para select de elementos
 * Utiliza la interfaz ControlValueAccessor
 *    <bit-select [domain]="'DOMAIN_TIPO_LOG'" id="tipolog" [control]="formControl">&nbsp;&nbsp;Tipus d'operació</bit-select>
 *
 * @input data: array de objetos a mostrar en el select. Puede ser null, en cuyo caso domain no puede ser null
 * @input domain: nombre del dominio que contiene los datos y que nos resolverá la página cuando cargue el componente. Puede ser null, en cuyo caso data no puede ser null
 * @input id: identificador del componente select
 * @input filter: true indicará que podemos buscar dentro del select, false que no.
 **/
var BitDropDownGeneralComponent = /** @class */ (function (_super) {
    __extends(BitDropDownGeneralComponent, _super);
    function BitDropDownGeneralComponent(router, sessionShared, ayudaService, changeDetectorRef) {
        var _this = _super.call(this, ayudaService, changeDetectorRef) || this;
        _this.router = router;
        _this.sessionShared = sessionShared;
        _this.ayudaService = ayudaService;
        _this.changeDetectorRef = changeDetectorRef;
        _this.hideLabel = false; // forzar no reservar espacio para el nombre del campo
        _this.listaOpciones = [];
        _this.listaOpcionesVisible = [];
        return _this;
    }
    BitDropDownGeneralComponent.prototype.ngOnInit = function () {
        var _this = this;
        _super.prototype.ngOnInit.call(this);
        if (this.data == null && this.domain != null) {
            //esta manera retornaría los datos alojados en el snapshot pero no tendríamos refresco en el caso de producirse
            //this.tiposLog = this.getTiposLogFromDomain(this.route.snapshot.data[TipoLog.DOMAIN_TIPO_LOG]);//this.route.data.pluck(TipoLog.DOMAIN_TIPO_LOG);
            //esta manera nos permite subscribirnos a los datos de data con lo que si hay refresco nos enteramos
            this.router.data.subscribe(function (result) {
                var dominios = result["dominios"];
                var domainTipo = dominios[_this.domain];
                if (domainTipo != null) {
                    domainTipo.subscribe(function (result) {
                        //console.log(result);
                        _this.sessionShared.set(_this.domain, result.slice()); // almacenamos en sesión una copia para evitar transmitir cambios
                        _this.listaOpciones = result.slice();
                        _this.postRetrieveData();
                    }, function (error) {
                        _this.listaOpciones = [{ value: null, label: "Error carrega dominis" }];
                    });
                }
                else {
                    console.log("No hay datos para el dominio", _this.domain);
                    _this.listaOpciones = [{ value: null, label: "Error carrega dominis" }];
                }
            });
        }
        else if (this.data) {
            // incluso si la lista de valores ha sido proporcionada,
            // hay que añadir algunos comportamientos posteriores
            this.listaOpciones = this.data.slice();
            this.postRetrieveData();
        }
        //console.log("Componente inicializado");
    };
    BitDropDownGeneralComponent.prototype.onBlur = function () {
        this.onTouchedCallback();
    };
    BitDropDownGeneralComponent.prototype.onFocus = function () {
        this.onTouchedCallback();
    };
    BitDropDownGeneralComponent.propDecorators = {
        hideLabel: [{ type: core_1.Input }],
        data: [{ type: core_1.Input }],
        domain: [{ type: core_1.Input }]
    };
    return BitDropDownGeneralComponent;
}(bit_custom_component_1.BitCustomComponent));
exports.BitDropDownGeneralComponent = BitDropDownGeneralComponent;
//# sourceMappingURL=bitdropdown-general.component.js.map